package com.example.myagenda

import android.content.Intent
import android.os.Bundle
import android.widget.ArrayAdapter
import android.widget.Toast
import androidx.activity.enableEdgeToEdge
import androidx.activity.result.ActivityResultLauncher
import androidx.activity.result.contract.ActivityResultContracts
import androidx.appcompat.app.AppCompatActivity
import androidx.core.view.ViewCompat
import androidx.core.view.WindowInsetsCompat
import androidx.recyclerview.widget.LinearLayoutManager
import com.example.myagenda.adapter.ContatoListAdapter
import com.example.myagenda.adapter.listener.ContatoOnClickListener
import com.example.myagenda.databinding.ActivityMainBinding

class MainActivity : AppCompatActivity() {

    private lateinit var binding : ActivityMainBinding
    private lateinit var adapter : ContatoListAdapter
    private lateinit var result : ActivityResultLauncher<Intent>
    private var listaContatos : ArrayList<Contato> = ArrayList()
    private var db = DBHelper(this)

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityMainBinding.inflate(layoutInflater)
        setContentView(binding.root)

        db = DBHelper(this)
        binding.recyclerViewContatos.layoutManager = LinearLayoutManager(applicationContext)

        atualizarLista()

        binding.buttonAdd.setOnClickListener {
            val novoContato = Intent(this, actNewContato::class.java)
            result.launch(novoContato)
        }

        result = registerForActivityResult(
            ActivityResultContracts.StartActivityForResult()) {
            if (it.data != null && it.resultCode == 1) {
                atualizarLista()
            }
            else {
                Toast.makeText(this, "Erro ao atualizar!", Toast.LENGTH_SHORT).show()
            }
        }
    }

    private fun atualizarLista() {
        listaContatos = db.listSelectAllContatos()
        adapter = ContatoListAdapter(listaContatos, ContatoOnClickListener {
            contato ->
            val intent = Intent(this, actEditContato::class.java)
            intent.putExtra("id", contato.id)
            result.launch(intent)
        } )
        binding.recyclerViewContatos.adapter = adapter
    }
}